@@ -202,8 +202,8 @@ Check.entry.pls = function(X, Y, ncomp, keepX, keepY, test.keepX, test.keepY,
     if (!(logratio %in% c("none", "CLR")))
         stop("Choose one of the two following logratio transformation: none or CLR")
     
-    # if DA and the unmapped Y has rows without associated class
-    if (DA) {
+    # if DA and the unmapped Y has rows without associated class, only run this check if Y is not null (ie multilevel)
+    if (DA && !is.null(Y)) {
       if (length(which(rowSums(Y)==0)) != 0) {
         stop("Unmapped Y contains samples with no associated class. May be caused by NAs in input Y vector")
       }
@@ -728,7 +728,7 @@ Check.entry.wrapper.mint.block = function(X,
     {
       vars <- apply(A[[q]], 2, sd)^2
       if (length(which(vars==0)) >0) {
-        stop(sprintf("There are features with zero variance in block '%s'. If nearZeroVar() function or 'near.zero.var' parameter hasn't been used,  please use it. If you have used one of these, you may need to manually filter out these features.", names(A)[q]), call.=F)
+        stop(sprintf("There are features with zero variance in block '%s'. If nearZeroVar() function or 'near.zero.var' parameter hasn't been used,  please use it. If you have used one of these, you may need to manually filter out these features.", names(A)[q]), call.=FALSE)
       }
     }
     return(list(A=A, ncomp=ncomp, study=study, keepA=keepA,
