@@ -76,6 +76,7 @@
 #' subsequent S3 methods} \item{max.iter}{the maximum number of iterations,
 #' used for subsequent S3 methods} \item{iter}{Number of iterations of the
 #' algorithm for each component}
+#' Note that the argument 'scheme' has now been hardcoded to 'horst' and 'init' to 'svd.single'. 
 #' @author Florian Rohart, Benoit Gautier, Kim-Anh Lê Cao, Al J Abadi
 #' @seealso \code{\link{spls}}, \code{\link{summary}}, \code{\link{plotIndiv}},
 #' \code{\link{plotVar}}, \code{\link{predict}}, \code{\link{perf}},
@@ -137,9 +138,7 @@ mint.block.plsda <- function(X,
                              study,
                              ncomp = 2,
                              design,
-                             scheme,
                              scale = TRUE,
-                             init ,
                              tol = 1e-06,
                              max.iter = 100,
                              near.zero.var = FALSE,
@@ -189,10 +188,10 @@ mint.block.plsda <- function(X,
         study = study,
         ncomp = ncomp,
         design = design,
-        scheme = scheme,
+        scheme = 'horst',
         mode = 'regression',
         scale = scale,
-        init = init,
+        init = 'svd.single',
         tol = tol,
         max.iter = max.iter,
         near.zero.var = near.zero.var,
