@@ -45,7 +45,8 @@
 #' cross validation (where each levels of object$study is left out (and
 #' predicted) once) and provides study-specific outputs
 #' (\code{study.specific.error}) as well as global outputs
-#' (\code{global.error}).
+#' (\code{global.error}). Note the mint perf methods do not use \code{seed}
+#' or \code{BPPARAM} arguments. 
 #' 
 #' AUROC. For PLS-DA, sPLS-DA, mint.PLS-DA, mint.sPLS-DA, and block.splsda
 #' methods: if \code{auc=TRUE}, Area Under the Curve (AUC) values are
@@ -104,8 +105,12 @@
 #' @param signif.threshold numeric between 0 and 1 indicating the significance
 #' threshold required for improvement in error rate of the components. Default
 #' to 0.01.
-#' @param cpus Number of cpus to use when running the code in parallel.
+#' @template arg/BPPARAM 
+#' @param seed set a number here if you want the function to give reproducible outputs. 
+#' Not recommended during exploratory analysis. Note if RNGseed is set in 'BPPARAM', this will be overwritten by 'seed'. 
+#' Note 'seed' is not required or used in perf.mint.plsda as this method uses loo cross-validation
 #' @param ... not used
+#' 
 #' @return For PLS and sPLS models, \code{perf} produces a list with the
 #' following components for every repeat: 
 #' \item{MSEP}{Mean Square Error Prediction for each \eqn{Y} variable, only 
@@ -137,19 +142,25 @@
 #' \item{cor.tpred, cor.upred}{Correlation between the 
 #' predicted and actual components for X (t) and Y (u)} 
 #' \item{RSS.tpred, RSS.upred}{Residual Sum of Squares between the
-#' predicted and actual components for X (t) and Y (u)} 
-#' \item{error.rate}{ For
-#' PLS-DA and sPLS-DA models, \code{perf} produces a matrix of classification
+#' predicted and actual components for X (t) and Y (u)}
+#' 
+#' 
+#'
+#' For PLS-DA and sPLS-DA models, \code{perf} produces a matrix of classification
 #' error rate estimation. The dimensions correspond to the components in the
 #' model and to the prediction method used, respectively. Note that error rates
 #' reported in any component include the performance of the model in earlier
 #' components for the specified \code{keepX} parameters (e.g. error rate
 #' reported for component 3 for \code{keepX = 20} already includes the fitted
-#' model on components 1 and 2 for \code{keepX = 20}). For more advanced usage
-#' of the \code{perf} function, see \url{www.mixomics.org/methods/spls-da/} and
-#' consider using the \code{predict} function.} 
-#' \item{auc}{Averaged AUC values
-#' over the \code{nrepeat}}
+#' model on components 1 and 2 for \code{keepX = 20}).
+#' \item{error.rate}{Prediction error rate for each dist and measure}
+#' \item{auc}{AUC values per component averaged over the \code{nrepeat}}
+#' \item{auc.all}{AUC values per component per repeat}
+#' \item{predict}{A list of length ncomp that os predicted values of each sample for each class}
+#' \item{features}{a list of features selected across the folds ($stable.X) for the keepX parameters from the input object.}
+#' \item{choice.ncomp}{Otimal number of components for the model for each prediction distance using one-sided t-tests that test 
+#' for a significant difference in the mean error rate (gain in prediction) when components are added to the model.}
+#' \item{class}{A list which gives the predicted class of each sample for each dist and each of the ncomp components}
 #' 
 #' For mint.splsda models, \code{perf} produces the following outputs:
 #' \item{study.specific.error}{A list that gives BER, overall error rate and
@@ -162,7 +173,7 @@
 #' \item{auc}{AUC values} \item{auc.study}{AUC values for each study in mint
 #' models}
 #' 
-#' For sgccda models, \code{perf} produces the following outputs:
+#' For sgccda models (i.e. block (s)PLS-DA models), \code{perf} produces the following outputs:
 #' \item{error.rate}{Prediction error rate for each block of \code{object$X}
 #' and each \code{dist}} \item{error.rate.per.class}{Prediction error rate for
 #' each block of \code{object$X}, each \code{dist} and each class}
@@ -193,12 +204,14 @@
 #' \item{WeightedVote.error.rate}{if more than one block, returns the error
 #' rate of the \code{WeightedVote} output} \item{weights}{Returns the weights
 #' of each block used for the weighted predictions, for each nrepeat and each
-#' fold} \item{choice.ncomp}{For supervised models; returns the optimal number
+#' fold} 
+#' \item{choice.ncomp}{For supervised models; returns the optimal number
 #' of components for the model for each prediction distance using one-sided
 #' t-tests that test for a significant difference in the mean error rate (gain
 #' in prediction) when components are added to the model. See more details in
 #' Rohart et al 2017 Suppl. For more than one block, an optimal ncomp is
 #' returned for each prediction framework.}
+#' 
 #' @author Ignacio González, Amrit Singh, Kim-Anh Lê Cao, Benoit Gautier,
 #' Florian Rohart, Al J Abadi
 #' @seealso \code{\link{predict}}, \code{\link{nipals}},
@@ -266,21 +279,25 @@ perf.mixo_pls <- function(object,
                           folds,
                           progressBar = FALSE,
                           nrepeat = 1,
+                          BPPARAM = SerialParam(),
+                          seed = NULL,
                           ...)
 {
+    # checking args and initialize params
     ncomp = object$ncomp
     spls.model <- is(object, 'mixo_spls')
     progressBar <- .check_logical(progressBar)
+    BPPARAM$RNGseed <- seed
     
-    # TODO add BPPARAM to args and use bplapply
+    # run CV in parallel depending on BPPARAM
     repeat_names <- .name_list(char = seq_len(nrepeat))
-    result <- lapply(X = repeat_names, FUN = function(nrep) {
+    result <- bplapply(X = repeat_names, FUN = function(nrep) {
         ## progress bar
-        if (progressBar == TRUE) # TODO drop for parallel
+        if (progressBar == TRUE)
             .progressBar(nrep/nrepeat)
         ## CV
         .perf.mixo_pls_cv(object, validation = validation, folds = folds, nrep = nrep)
-    })
+    }, BPPARAM = BPPARAM)
     
     measures <- lapply(result, function(x){
         x$measures
@@ -561,7 +578,7 @@ perf.mixo_spls  <- perf.mixo_pls
             u.cv = spls.res$variates$Y[, 1]
             t.cv = spls.res$variates$X[, 1]
             a.cv = spls.res$loadings$X[, 1]
-            b.cv = spls.res$loadings$Y[, 1, drop = F]
+            b.cv = spls.res$loadings$Y[, 1, drop = FALSE]
             
             # reg coefficients:
             c.cv = crossprod(X.train, u.cv) / drop(crossprod(u.cv)) 
@@ -745,11 +762,14 @@ perf.mixo_plsda <- function(object,
                             auc = FALSE,
                             progressBar = FALSE,
                             signif.threshold = 0.01,
-                            cpus = 1,
+                            BPPARAM = SerialParam(),
+                            seed = NULL,
                             ...)
 {
     
     #-- initialising arguments --#
+    set.seed(seed)
+    BPPARAM$RNGseed <- seed
     # these data are the centered and scaled X output or the unmapped(Y) scaled and centered
     X = object$input.X
     level.Y = object$names$colnames$Y  #to make sure the levels are ordered
@@ -812,7 +832,7 @@ perf.mixo_plsda <- function(object,
     if (any(table(object$Y) <= 1)) {
         stop(paste("Cannot evaluate performance when a class level ('", 
                    names(table(object$Y))[which(table(object$Y) == 1)],
-                   "') has only a single assocaited sample.", sep = ""))
+                   "') has only a single associated sample.", sep = ""))
     }
     
     if (nrepeat < 3 && validation != "loo") {
@@ -835,31 +855,6 @@ perf.mixo_plsda <- function(object,
     #-- check significance threshold
     signif.threshold <- .check_alpha(signif.threshold)
     
-    cpus <- .check_cpus(cpus)
-    parallel <- cpus > 1
-    
-    if (parallel)
-    {
-        if (.onUnix()) {
-            cl <- makeForkCluster(cpus)
-        } else {
-            cl <- makePSOCKcluster(cpus)
-        }
-        
-        on.exit(stopCluster(cl))
-        #clusterExport(cl, c("splsda","selectVar"))
-        clusterEvalQ(cl, library(mixOmics))
-        
-        if (!is.null(list(...)$seed)) { ## for unit tests purpose
-            RNGversion(.mixo_rng()) ## bc different R versions can have different RNGs and we want reproducible unit tests
-            clusterSetRNGStream(cl = cl, iseed = list(...)$seed)
-        }
-    } else {
-        parallel = FALSE
-        cl = NULL
-    }
-    
-    
     #---------------------------------------------------------------------------#
     #-- logration + multilevel approach ----------------------------------------#
     # we can do logratio and multilevel on the whole data as these transformation are done per sample
@@ -954,9 +949,6 @@ perf.mixo_plsda <- function(object,
     }
     
     class.object=class(object)
-    if (parallel) {
-        clusterExport(cl, c("X","Y","is.na.A","misdata","scale","near.zero.var","class.object","keepX"),envir=environment())
-    }
     
     for (comp in 1 : ncomp)
     {
@@ -975,11 +967,13 @@ perf.mixo_plsda <- function(object,
         #test.keepX is a value
         
         # estimate performance of the model for each component
+        set.seed(seed)
         result = MCVfold.spls (X, Y, multilevel = multilevel, validation = validation, folds = folds, nrepeat = nrepeat, ncomp = comp,
                                choice.keepX = choice.keepX, test.keepX = test.keepX, test.keepY = nlevels(Y),
                                measure = measure, dist = dist, scale=scale,
                                near.zero.var = near.zero.var,
-                               auc = auc, progressBar = progressBar, class.object = class.object, cl = cl, parallel = parallel,
+                               auc = auc, progressBar = progressBar, class.object = class.object,
+                               BPPARAM = BPPARAM,
                                misdata = misdata, is.na.A = is.na.A)#, ind.NA = ind.NA, ind.NA.col = ind.NA.col)
         
         # ---- extract stability of features ----- # NEW
@@ -1033,7 +1027,13 @@ perf.mixo_plsda <- function(object,
             }
             else
             {
-                ncomp_opt[measure, ijk] = which(t(rowMeans(mat.error.rate[[measure_i]][[ijk]])) == min(t(rowMeans(mat.error.rate[[measure_i]][[ijk]]))))
+                if(length(min(t(rowMeans(mat.error.rate[[measure_i]][[ijk]])))) > 1){
+                    # avoid multiple replacements - fix for issue #303
+                    print("More than one component found with same minimum error rate, selecting smaller component...")
+                    ncomp_opt[measure, ijk] = which(t(rowMeans(mat.error.rate[[measure_i]][[ijk]])) == min(t(rowMeans(mat.error.rate[[measure_i]][[ijk]]))))[1]
+                } else{
+                    ncomp_opt[measure, ijk] = which(t(rowMeans(mat.error.rate[[measure_i]][[ijk]])) == min(t(rowMeans(mat.error.rate[[measure_i]][[ijk]]))))
+                }
             }
         }
     }
