@@ -15,9 +15,10 @@
 #' supplemental material of the mixOmics article (Rohart et al. 2017). More
 #' details about the PLS modes are in \code{?pls}.
 #' 
+#' @inheritParams block.splsda
 #' @param method This parameter is used to pass all other argument to the
 #' suitable function. \code{method} has to be one of the following: "spls",
-#' "splsda", "mint.splsda", "rcc", "pca", "spca" or "pls".
+#' "splsda", "block.splsda", "mint.splsda", "rcc", "pca", "spca" or "pls".
 #' @param X numeric matrix of predictors. \code{NA}s are allowed.
 #' @param Y Either a factor or a class vector for the discrete outcome, or a
 #' numeric vector or matrix of continuous responses (for multi-response
@@ -75,8 +76,16 @@
 #' @param tol Numeric, convergence tolerance criteria.
 #' @param light.output if set to FALSE, the prediction/classification of each
 #' sample for each of \code{test.keepX} and each comp is returned.
+#' @param weighted tune using either the performance of the Majority vote or
+#' the Weighted vote.
+#' @param signif.threshold numeric between 0 and 1 indicating the significance
+#' threshold required for improvement in error rate of the components. Default
+#' to 0.01.
+#' @param V Matrix used in the logratio transformation id provided (for tune.pca)
 #' @param BPPARAM A \linkS4class{BiocParallelParam} object indicating the type
 #'   of parallelisation. See examples.
+#' @param seed set a number here if you want the function to give reproducible outputs. 
+#' Not recommended during exploratory analysis. Note if RNGseed is set in 'BPPARAM', this will be overwritten by 'seed'. 
 #' @return Depending on the type of analysis performed and the input arguments,
 #' a list that may contain:
 #' 
@@ -154,122 +163,203 @@
 #' @export
 #' @example ./examples/tune-examples.R
 tune <-
-    function (method = c("spls", "splsda", "mint.splsda", "rcc", "pca", "spca"),
+    function (method = c("pls", "spls", "plsda", "splsda", "block.plsda", "block.splsda", "mint.plsda", "mint.splsda", "rcc", "pca", "spca"),
+              # Input data
               X,
               Y,
-              multilevel = NULL,
-              ncomp,
-              study,
-              # mint.splsda
+              # Sparse params
               test.keepX = c(5, 10, 15),
-              # all but pca, rcc
               test.keepY = NULL,
-              # rcc, multilevel
               already.tested.X,
-              # all but pca, rcc
               already.tested.Y,
-              #multilevel
-              mode = c("regression", "canonical", "invariant", "classic"),
-              # multilevel
-              nrepeat = 1,
-              #multilevel, splsda
-              grid1 = seq(0.001, 1, length = 5),
-              # rcc
-              grid2 = seq(0.001, 1, length = 5),
-              # rcc
+              # Number of components
+              ncomp,
+
+              ## Params related to model building
+              V, # PCA
+              center = TRUE, # PCA
+              grid1 = seq(0.001, 1, length = 5), # CCA
+              grid2 = seq(0.001, 1, length = 5), # CCA
+              mode = c("regression", "canonical", "invariant", "classic"), # PLS
+              indY, # block PLSDA
+              weighted = TRUE, # block PLSDA
+              design, # block PLSDA
+              study, # MINT PLSDA
+              tol = 1e-09, # PLSDA, block PLSDA, mint PLSDA, PCA
+              scale = TRUE, # PLS, PLSDA, block PLSDA, mint PLSDA, PCA
+              logratio = c('none','CLR'), # PLS, PLSDA, PCA
+              near.zero.var = FALSE, # PLS, PLSDA, block PLSDA, mint PLSDA
+              max.iter = 100, # PLS, PLSDA, block PLSDA, mint PLSDA, PCA
+              multilevel = NULL, # PLS, PLSDA, PCA
+
+              ## Params related to cross-validation
               validation = "Mfold",
-              # all but pca
+              nrepeat = 1,
               folds = 10,
-              # all but pca
+              signif.threshold = 0.01,
+
+              # How to measure accuracy - only for DA methods
               dist = "max.dist",
-              # all but pca, rcc
               measure = ifelse(method == "spls", "cor", "BER"),
-              # all but pca, rcc
               auc = FALSE,
+
+              # Running params
+              seed = NULL,
+              BPPARAM = SerialParam(),
               progressBar = FALSE,
-              # all but pca, rcc
-              near.zero.var = FALSE,
-              # all but pca, rcc
-              logratio = c('none','CLR'),
-              # all but pca, rcc
-              center = TRUE,
-              # pca
-              scale = TRUE,
-              # mint, splsda
-              max.iter = 100,
-              #pca
-              tol = 1e-09,
-              #pca
-              light.output = TRUE,
-              # mint, splsda
-              BPPARAM = SerialParam()
+
+              # Output params
+              light.output = TRUE
               
     )
     {
+
+        ## ----------- checks ----------- ##
+
         method = match.arg(method)
         mode <- match.arg(mode)
-        
-        if (method == "mint.splsda") {
-            message("Calling 'tune.mint.splsda' with Leave-One-Group-Out Cross Validation (nrepeat = 1)")
-            
-            if (missing(ncomp))
-                ncomp = 1
-            
-            result = tune.mint.splsda(X = X, Y = Y,
-                                      ncomp = ncomp,
-                                      study = study,
-                                      test.keepX = test.keepX,
-                                      already.tested.X = already.tested.X,
-                                      dist = dist,
-                                      measure = measure,
-                                      auc = auc,
-                                      progressBar = progressBar,
-                                      scale = scale,
-                                      tol = tol,
-                                      max.iter = max.iter,
-                                      near.zero.var = near.zero.var,
-                                      light.output = light.output)
-            
-        } else if (method == "rcc") {
-            message("Calling 'tune.rcc'")
-            
-            result = tune.rcc(X = X,
-                              Y = Y,
-                              grid1 = grid1,
-                              grid2 = grid2,
-                              validation = validation,
-                              folds = folds,
-                              plot = plot)
-            
-        } else if (method == "pca") {
+
+        # hardcode scheme and init
+        scheme = "horst"
+        init = "svd.single"
+
+
+        ## ----------- PCA ----------- ##
+
+        if (method == "pca") {
             message("Calling 'tune.pca'")
             
             if (missing(ncomp))
                 ncomp = NULL
             
-            result = tune.pca(X = X,
-                              ncomp = ncomp,
-                              center = center,
-                              scale = scale,
-                              max.iter = max.iter,
-                              tol = tol)
-            
-            
+            result = tune.pca(
+                # model building params
+                X = X, ncomp = ncomp,
+                center = center, scale = scale, max.iter = max.iter, tol = tol)
+
+        ## ----------- sPCA ----------- ##
+
         } else if (method == "spca") {
             message("Calling 'tune.spca'")
             
             if (missing(ncomp))
                 ncomp = 2
             #TODO use match.call() arg matching for these function calls
-            result = tune.spca(X = X,
-                               ncomp = ncomp,
-                               nrepeat = nrepeat,
-                               folds = folds,
-                               test.keepX = test.keepX,
-                               center = center,
-                               scale = scale)
+            result = tune.spca(
+                # model building params
+                X = X, ncomp = ncomp,
+                center = center, scale = scale,
+                # sparsity params
+                test.keepX = test.keepX,
+                # CV params
+                nrepeat = nrepeat, folds = folds,
+                # running params
+                BPPARAM = BPPARAM, seed = seed)
+
+
+        ## ----------- CCA ----------- ##
+
+        } else if (method == "rcc") {
+            message("Calling 'tune.rcc'")
             
+            result = tune.rcc(
+                # model building params
+                X = X, Y = Y,
+                # sparsity params
+                grid1 = grid1, grid2 = grid2,
+                # CV params
+                validation = validation, folds = folds,
+                # running params
+                BPPARAM = BPPARAM, seed = seed)
+
+        ## ----------- PLS ----------- ##
+
+        } else if (method == "pls") {
+            message("Calling 'tune.pls'")
             
+            result = tune.pls(
+                # model building params
+                X = X, Y = Y, ncomp = ncomp, mode = mode,
+                scale = scale, logratio = logratio, tol = tol, 
+                max.iter = max.iter, near.zero.var = near.zero.var,
+                # CV params
+                validation = validation, nrepeat = nrepeat, folds = folds,
+                # PA params
+                measure = measure,
+                # running params
+                progressBar = progressBar,
+                BPPARAM = BPPARAM, seed = seed) 
+                
+                # multilevel??
+
+        ## ----------- sPLS +/- multilevel ----------- ##
+
+        } else if (method == "spls") {
+            if(missing(multilevel))
+            {
+                message("Calling 'tune.spls'")
+                
+                result = tune.spls(
+                    # model building params
+                    X = X, Y = Y, ncomp = ncomp, mode = mode,
+                    scale = scale, logratio = logratio, tol = tol, 
+                    max.iter = max.iter, near.zero.var = near.zero.var,
+                    # sparsity params
+                    test.keepX = test.keepX, test.keepY = test.keepY,
+                    # CV params
+                    validation = validation, nrepeat = nrepeat, folds = folds,
+                    # PA params
+                    measure = measure,
+                    # running params
+                    progressBar = progressBar,
+                    BPPARAM = BPPARAM, seed = seed) 
+                    
+                    } else {
+                message("Calling 'tune.splslevel' with method = 'spls'")
+                
+                if (missing(ncomp))
+                    ncomp = 1
+                if (missing(already.tested.X))
+                  already.tested.X = NULL
+                if (missing(already.tested.Y))
+                    already.tested.Y = NULL
+                
+                result = tune.splslevel(
+                    # model building params
+                    X = X, Y = Y, ncomp = ncomp, mode = mode,
+                    # multilevel params
+                    multilevel = multilevel,
+                    # sparsity params
+                    test.keepX = test.keepX, test.keepY = test.keepY,
+                    already.tested.X = already.tested.X, already.tested.Y = already.tested.Y,
+                    # running params
+                    BPPARAM = BPPARAM, seed = seed)
+            }
+
+        ## ----------- plsda ----------- ##
+
+        } else if (method == "plsda") {
+            
+            message("Calling 'tune.plsda'")
+            
+            if (missing(ncomp))
+                ncomp = 1
+            
+            result = tune.plsda(
+                # model building params
+                X = X, Y = Y, ncomp = ncomp, multilevel = multilevel,
+                scale = scale, logratio = logratio, tol = tol, 
+                max.iter = max.iter, near.zero.var = near.zero.var,
+                # CV params
+                validation = validation, folds = folds, nrepeat = nrepeat,
+                # PA params
+                dist = dist, auc = auc,
+                # running params
+                progressBar = progressBar, light.output = light.output,
+                BPPARAM = BPPARAM, seed = seed)
+
+        ## ----------- splsda ----------- ##
+
         } else if (method == "splsda") {
             
             message("Calling 'tune.splsda'")
@@ -277,56 +367,101 @@ tune <-
             if (missing(ncomp))
                 ncomp = 1
             
-            result = tune.splsda (X = X, Y = Y,
-                                  ncomp = ncomp,
-                                  test.keepX = test.keepX,
-                                  already.tested.X = already.tested.X,
-                                  validation = validation,
-                                  folds = folds,
-                                  dist = dist ,
-                                  measure = measure,
-                                  auc = auc,
-                                  progressBar = progressBar,
-                                  max.iter = max.iter,
-                                  near.zero.var = near.zero.var,
-                                  nrepeat = nrepeat,
-                                  logratio = logratio,
-                                  multilevel = multilevel,
-                                  light.output = light.output)
-        } else if (method == "spls") {
-            if(missing(multilevel))
-            {
-                message("Calling 'tune.spls'")
-                
-                result = tune.spls(X = X,
-                                   Y = Y,
-                                   test.keepX = test.keepX,
-                                   test.keepY = test.keepY,
-                                   ncomp = ncomp,
-                                   validation = validation,
-                                   nrepeat = nrepeat,
-                                   folds = folds,
-                                   mode = mode,
-                                   measure = measure,
-                                   BPPARAM = BPPARAM,
-                                   progressBar = progressBar
-                )
-            } else {
-                message("Calling 'tune.splslevel' with method = 'spls'")
-                
-                if (missing(ncomp))
-                    ncomp = 1
-                if (missing(already.tested.Y))
-                    already.tested.Y = NULL
-                
-                result = tune.splslevel(X = X, Y = Y,
-                                        multilevel = multilevel,
-                                        mode = mode,
-                                        ncomp = ncomp, test.keepX = test.keepX, test.keepY = test.keepY,
-                                        already.tested.X = already.tested.X, already.tested.Y = already.tested.Y)
-            }
-        }
+            result = tune.splsda(
+                # model building params
+                X = X, Y = Y, ncomp = ncomp, multilevel = multilevel,
+                scale = scale, logratio = logratio, tol = tol, 
+                max.iter = max.iter, near.zero.var = near.zero.var,
+                # sparsity params
+                test.keepX = test.keepX, already.tested.X = already.tested.X,
+                # CV params
+                validation = validation, folds = folds, nrepeat = nrepeat,
+                # PA params
+                dist = dist, measure = measure, auc = auc,
+                # running params
+                progressBar = progressBar, light.output = light.output,
+                BPPARAM = BPPARAM, seed = seed)
+
+
+        ## ----------- block.plsda ----------- ##
+
+        } else if (method == "block.plsda") {
+          message("Calling 'tune.block.plsda'")
+          
+          result = tune.block.plsda(
+            # model building params
+            X = X, Y = Y, indY = indY, ncomp = ncomp, design = design,
+            tol = tol, scale = scale, max.iter = max.iter, near.zero.var = near.zero.var,
+            # CV params
+            validation = validation, folds = folds, nrepeat = nrepeat, signif.threshold = signif.threshold,
+            # PA params
+            dist = dist, weighted = weighted, 
+            # running params
+            progressBar = progressBar, light.output = light.output,
+            BPPARAM = BPPARAM, seed = seed)
+
+
+        ## ----------- block.splsda ----------- ##
+
+        } else if (method == "block.splsda") {
+          message("Calling 'tune.block.splsda'")
+          
+          result = tune.block.splsda(
+            # model building params
+            X = X, Y = Y, indY = indY, ncomp = ncomp, design = design,
+            tol = tol, scale = scale, max.iter = max.iter, near.zero.var = near.zero.var,
+            # sparsity params
+            test.keepX = test.keepX, already.tested.X = already.tested.X,
+            # CV params
+            validation = validation, folds = folds, nrepeat = nrepeat, signif.threshold = signif.threshold,
+            # PA params
+            dist = dist, weighted = weighted, measure = measure,
+            # running params
+            progressBar = progressBar, light.output = light.output,
+            BPPARAM = BPPARAM, seed = seed)
+
         
+        ## ----------- mint.plsda ----------- ##
+
+        } else if (method == "mint.plsda") {
+            message("Calling 'tune.mint.plsda' with Leave-One-Group-Out Cross Validation (nrepeat = 1)")
+            
+            if (missing(ncomp))
+                ncomp = 1
+            
+            result = tune.mint.plsda(
+                # model building params
+                X = X, Y = Y, ncomp = ncomp, study = study,
+                scale = scale, tol = tol, max.iter = max.iter, near.zero.var = near.zero.var,
+                # PA params
+                dist = dist, auc = auc,
+                # running params - no need for seed or BPPARAM due to LOO CV
+                progressBar = progressBar,light.output = light.output)
+
+
+        ## ----------- mint.splsda ----------- ##
+
+        } else if (method == "mint.splsda") {
+            message("Calling 'tune.mint.splsda' with Leave-One-Group-Out Cross Validation (nrepeat = 1)")
+            
+            if (missing(ncomp))
+                ncomp = 1
+            
+            result = tune.mint.splsda(
+                # model building params
+                X = X, Y = Y, ncomp = ncomp, study = study,
+                scale = scale, tol = tol, max.iter = max.iter, near.zero.var = near.zero.var,
+                # sparsity params
+                test.keepX = test.keepX, already.tested.X = already.tested.X,
+                # PA params
+                dist = dist, measure = measure, auc = auc,
+                # running params - no need for seed or BPPARAM due to LOO CV
+                progressBar = progressBar,light.output = light.output)
+
+        } 
+
+        ## ----------- end ----------- ##
+            
         result$call = match.call()
         return(result)
     }
